@@ -19,24 +19,26 @@ import sys, os, re
 from glob import glob
 from kook.utils import read_file, write_file
 
-release   = prop('release', '0.8.0')
+release   = prop('release', '0.9.0')
 package   = prop('package', 'Oktest')
 copyright = prop('copyright', "copyright(c) 2010-2011 kuwata-lab.com all rights reserved")
 license   = "MIT License"
-kook_default_product = 'test'
+kook_default_product = 'unittest'
 
 python = prop('python', 'python')
 
 
 python_binaries = [
     ('2.4', '/opt/local/bin/python2.4'),
-    ('2.5', '/opt/local/bin/python2.5'),
-    ('2.6', '/opt/local/bin/python2.6'),
+    #('2.5', '/opt/local/bin/python2.5'),
+    #('2.6', '/opt/local/bin/python2.6'),
     #('2.7', '/opt/local/bin/python2.7'),
-    ('2.7', '/usr/local/python/2.7.1/bin/python'),
-    ('3.0', '/usr/local/python/3.0.1/bin/python'),
-    ('3.1', '/usr/local/python/3.1/bin/python'),
-    ('3.2', '/usr/local/python/3.2rc1/bin/python'),
+    ('2.5', '/opt/lang/python/2.5.5/bin/python'),
+    ('2.6', '/opt/lang/python/2.6.7/bin/python'),
+    ('2.7', '/opt/lang/python/2.7.2/bin/python'),
+    ('3.0', '/opt/lang/python/3.0.1/bin/python'),
+    ('3.1', '/opt/lang/python/3.1.4/bin/python'),
+    ('3.2', '/opt/lang/python/3.2.0/bin/python'),
 ]
 
 
@@ -54,7 +56,23 @@ def _with_backup(filepath):
     return deco
 
 
-TEST_NAMES = ('oktest', 'helpers', 'tracer', 'doc')
+TEST_NAMES = ('oktest', 'helpers', 'tracer', 'spec', 'testdeco',
+              'doc', 'assertions', 'dummy', 'runner', 'util')
+test_names = [ os.path.basename(x).replace('_test.py', '')
+                   for x in glob("test/*_test.py") ]
+assert set(TEST_NAMES) == set(test_names)
+
+
+@recipe
+@spices("-a: do with python from 2.4 to 3.2", "[testnames...]")
+def task_unittest(c, *args, **kwargs):
+    #optstr = " -m oktest"
+    optstr = " -m oktest -sp test"
+    if kwargs.get('a'):
+        for ver, execpath in python_binaries:
+            system_f(execpath + optstr)
+    else:
+        system(sys.executable + optstr)
 
 
 @recipe
@@ -85,6 +103,13 @@ def task_test(c, *args, **kwargs):
         for func in funcs:
             func(c, ver, bin)
 
+for tname in TEST_NAMES:
+    exec(r'''
+def _run_%s_test(c, ver, bin):
+    fpath = 'test/%s_test.py'
+    _invoke_test(c, ver, bin, fpath)
+''' % (tname, tname))
+
 
 def _run_oktest_test(c, ver, bin):
     """invoke 'test/oktest_test.py'"""
@@ -102,18 +127,6 @@ def _run_oktest_test(c, ver, bin):
         system(cmd)
 
 
-def _run_helpers_test(c, ver, bin):
-    """invoke 'test/helpers_test.py'"""
-    fpath = 'test/helpers_test.py'
-    _invoke_test(c, ver, bin, fpath)
-
-
-def _run_tracer_test(c, ver, bin):
-    """invoke 'test/tracer_test.py'"""
-    fpath = 'test/tracer_test.py'
-    _invoke_test(c, ver, bin, fpath)
-
-
 def _invoke_test(c, ver, bin, fpath):
     def replacer_for_py24(s):
         s = re.sub(r'(from __future__ import .*)', r'#\1', s)
@@ -150,6 +163,8 @@ def file_doc_test_py(c):
     m = re.compile(pat, re.S).search(cont)
     s = m.group(1)
     s = re.compile(r'^(\S)', re.M).sub(r'#\1', s)
+    s = re.compile(r'^( *)(\$ python)', re.M).sub(r'\1#\2', s)
+    s = re.sub(r'\{\{\*(.*?)\*\}\}', r'\1', s)
     #
     f = open(c.product, 'w')
     f.write(
@@ -197,12 +212,26 @@ def task_package(c):
     pass
 
 
+def _with_backup(fn):
+    fname = "README.txt"
+    try:
+        f = open(fname); s = f.read(); f.close()
+        os.rename(fname, fname + ".bkup")
+        s = s.replace("{{*", "").replace("*}}", "")
+        f = open(fname, 'w'); f.write(s); f.close()
+        fn()
+    finally:
+        os.rename(fname + ".bkup", fname)
+
+
 @recipe
 @ingreds('edit')
 def task_sdist(c, *args, **kwargs):
     """create dist/Oktest-X.X.X.tar.gz"""
     #rm_rf(c%"dist/$(package)-$(release)*")
-    system(c%'$(python) setup.py sdist --force-manifest')   # or setup.py sdist --keep-temp
+    @_with_backup
+    def fn():
+        system(c%'$(python) setup.py sdist')   # or setup.py sdist --keep-temp
     #with chdir('dist') as d:
     #    targz = c%"$(package)-$(release).tar.gz"
     #    #tar_xzf(targz)
@@ -225,27 +254,33 @@ def _do_setup_py(c, command):
 @ingreds('edit')
 def task_eggs(c):
     """create dist/*.egg files"""
-    _do_setup_py(c, "$(bin) setup.py bdist_egg")
+    @_with_backup
+    def fn():
+        _do_setup_py(c, "$(bin) setup.py bdist_egg")
 
 
 @recipe
 @ingreds('edit')
 def task_register(c):
     """register information into PyPI"""
-    system(c%"$(python) setup.py register")
+    @_with_backup
+    def fn():
+        system(c%"$(python) setup.py register")
 
 
 @recipe
 @ingreds('edit')
 def task_upload(c):
     """upload packages"""
-    system(c%"$(python) setup.py sdist upload")
-    _do_setup_py(c, "$(bin) setup.py bdist_egg upload")
+    @_with_backup
+    def fn():
+        system(c%"$(python) setup.py sdist upload")
+        _do_setup_py(c, "$(bin) setup.py bdist_egg upload")
 
 
 @recipe
 def task_clean(c):
-    rm_rf('**/*.pyc', 'dist', 'build', 'lib/*.egg-info', c%'$(package).zip')
+    rm_rf('**/*.pyc', '**/__pycache__', 'dist', 'build', 'lib/*.egg-info', c%'$(package).zip')
 
 
 @recipe
@@ -259,8 +294,11 @@ def file_website_index_html(c):
     opts = '--stylesheet-path=style.css --link-stylesheet --strip-class=field --strip-class=field-name --strip-class=field-body'
     system(c%'rst2html.py $(opts) $(ingred) > $(product)')
     def f(s):
-        s = s.replace('README', 'Oktest - a new style testing library -')
+        s = re.sub('<\?xml version=".*" encoding=".*" *\?>\n', '', s)
+        s = s.replace('Oktest README', 'Oktest - a new style testing library -')
         s = s.replace('See CHANGES.txt', 'See <a href="CHANGES.txt">CHANGES.txt</a>')
+        s = s.replace('{{*', '<strong>')
+        s = s.replace('*}}', '</strong>')
         #s = re.sub(r'^<h(\d)>(.*?)</h\d>', r, s)
         pat = re.compile(r'^<h(\d)>(.*?)</h\d>', re.M)
         def r(m):
@@ -271,12 +309,20 @@ def file_website_index_html(c):
         return s
     edit(c.product, by=f)
 
+
+@recipe
+def task_manifest(c):
+    """update MANIFEST file"""
+    system(c%'$(python) setup.py sdist --force-manifest')
+
+
 @recipe
 @product('website/CHANGES.txt')
 @ingreds('CHANGES.txt')
 def file_CHANGES_txt(c):
     cp(c.ingred, c.product)
 
+
 @recipe
 @product('Oktest.zip')
 @ingreds('website/index.html', 'website/CHANGES.txt')
@@ -285,6 +331,7 @@ def file_Oktest_zip(c):
     with chdir("website"):
         system("zip -r ../Oktest.zip index.html style.css CHANGES.txt")
 
+
 @recipe
 @ingreds('Oktest.zip')
 def task_website(c):
